import java.util.Hashtable;

public class SymbolTable {

	public static enum SymbolType  {
		FUNCTION, VARIABLE;
	};

	static class Symbol {
		private String name;
		private	DataType datatype;
		private SymbolType symboltype;
		private ValueObject value;
		public Symbol(String _name, 
			      DataType _datatype,
			      SymbolType _symboltype
			) {
			name = _name;
			datatype = _datatype;
			symboltype = _symboltype;
		}
		public String getName() {
			return name;
		}
		public DataType getDataType() {
			return datatype;
		}		
		public SymbolType getSymbolType() {
			return symboltype;
		}
		public ValueObject getValue() {
			return value;
		}		       
		public void setValue(ValueObject vo) {
			value = vo;
		}		       

	};

	Hashtable<String, Symbol> symbols = new Hashtable<String, Symbol>();

	SymbolTable() {

	}

	public Symbol put(String symbol, DataType datatype, SymbolType symboltype) {		
		Symbol tmp = new Symbol(symbol, datatype, symboltype);
		symbols.put(symbol, tmp);
		return tmp;
	}

	public void putVariable(String symbol, DataType datatype) {
		Symbol sb = put(symbol, datatype, SymbolType.VARIABLE);
		switch (datatype) {
		case FLOATING_POINT:		       		       
			sb.setValue(new ValueObject(0.0));
			break;
		case STRING:
			sb.setValue(new ValueObject(""));
			break;
		case INTEGER:
			sb.setValue(new ValueObject(0));
		}
	}
	
	public Symbol get(String name) {
		return symbols.get(name);
	}

	public void setValue(String name, ValueObject value) {
		symbols.get(name).setValue(value);
	}

	boolean defined(String name) {
		return symbols.get(name)!=null;
	}
}
